@@ -9,10 +9,11 @@ def flush_updates(function):
     """
     Decorator that flushes ElasticSearch updates.
     """
+
     @functools.wraps(function)
     def wrap(*args, **kwargs):
         try:
-            return function(*args)
+            return function(*args, **kwargs)
         finally:
             queue_flush()
 
